@@ -8,7 +8,6 @@ import urllib.error
 import urllib.parse
 import urllib.request
 
-unescape = html.parser.HTMLParser().unescape  # type: ignore
 
 TIMEOUT = 15
 tests = {
@@ -34,16 +33,21 @@ tests = {
     'ast-spa': ('nin', 'ni'),
     'bre-fra': ('Na', 'Ni'),
     'bul-mkd': ('аз', 'јас'),
-    'cat-eng': ('Ens', 'Us'),
-    'cat-eng_US': ('Ens', 'Us'),
+    'cat-eng': ('Ens', 'Body'),
+    'cat-eng_US': ('Ens', 'Body'),
     'cat-epo': ('Per', 'Por'),
     'cat-fra': ('per', 'par'),
     'cat-oci': ('Tinc', 'Ai'),
     'cat-oci_aran': ('Tinc', 'È'),
     'cat-por': ('tinc', 'tenho'),
+    'cat-por_br': ('tinc', 'tenho'),
+    'cat-por_BR': ('tinc', 'tenho'),
+    'cat-por_PTpre1990': ('tinc', 'tenho'),
     'cat-spa': ('Jo', 'Yo'),
     'cym-eng': ('Yn', 'In'),
     'eng-cat': ('us', 'ens'),
+    'eng-cat_iec2017': ('us', 'ens'),
+    'eng-cat_valencia': ('us', 'ens'),
     'eng-epo': ('And', 'Kaj'),
     'eng-glg': ('Only', 'Só'),
     'eng-spa': ('hello', 'hola'),
@@ -57,13 +61,15 @@ tests = {
     'glg-por': ('teño', 'tenho'),
     'glg-spa': ('Teño', 'Tengo'),
     'hbs-slv': ('Slobodnu', 'Svobodnemu'),
-    'ind-msa': ('sedangkan', 'manakala'),
-    'msa-ind': ('manakala', 'sedangkan'),
+    'ind-zlm': ('sedangkan', 'manakala'),
+    'zlm-ind': ('manakala', 'sedangkan'),
     'isl-eng': ('Grein', 'Article'),
     'isl-swe': ('af', 'av'),
     'ita-cat': ('dire', 'dir'),
     'ita-srd': ('cane', 'cane'),
     'cat-srd': ('gos', 'cane'),
+    'cat-ita': ('gos', 'cane'),
+    'cat-ron': ('gos', 'câine'),
     'kaz-tat': ('ол', 'ул'),
     'mkd-bul': ('јас', 'аз'),
     'mkd-eng': ('триесет', 'thirty'),
@@ -90,6 +96,8 @@ tests = {
     'por-glg': ('tenho', 'teño'),
     'por-spa': ('tenho', 'tengo'),
     'ron-spa': ('Liberă', 'Libre'),
+    'ron-cat': ('Liberă', 'Lliure'),
+    'ron-cat_iec2017': ('Liberă', 'Lliure'),
     'slv-hbs_BS': ('Svobodnemu', 'Slobodnu'),
     'slv-hbs_HR': ('Svobodnemu', 'Slobodnu'),
     'slv-hbs_SR': ('Svobodnemu', 'Slobodnu'),
@@ -99,6 +107,7 @@ tests = {
     'sme-nob': ('ja', 'og'),
     'spa-ast': ('ni', 'nin'),
     'spa-cat': ('yo', 'jo'),
+    'spa-cat_iec2017': ('yo', 'jo'),
     'spa-cat_valencia': ('tengo', 'tinc'),
     'spa-eng': ('hola', 'hello'),
     'spa-eng_US': ('hola', 'hello'),
@@ -112,7 +121,7 @@ tests = {
     'swe-dan': ('vad', 'hvad'),
     'dan-swe': ('hvad', 'vad'),
     'swe-isl': ('Av', 'Af'),
-    'tat-kaz': ('ул', 'ол'),
+    'tat-kaz': ('ул', 'ұл'),
     'spa-ita': ('natación', 'nuoto'),
     'ita-spa': ('nuoto', 'natación'),
 }
@@ -129,14 +138,20 @@ def test_pair(pair, host):
         response = urllib.request.urlopen('%s/translate?langpair=%s&q=%s' %
                                           (host, langpair, intext), timeout=TIMEOUT).read().decode('utf-8')
     except urllib.error.HTTPError as e:
-        print('%s failed with error code %s and reason: %s' % (pair, e.code, e.reason))
+        explanation = ''
+        try:
+            explanation = e.read().decode()
+        except Exception:
+            pass
+        print('%s failed with error code %s and reason: %s, response body: %s' %
+              (pair, e.code, e.reason, explanation))
         return False
     except socket.timeout as e:
         print('%s failed: %s' % (pair, e))
         return False
     js = json.loads(response)
     translation_raw = js['responseData']['translatedText']
-    translation = unescape(urllib.parse.unquote_plus(translation_raw)).strip()
+    translation = html.unescape(urllib.parse.unquote_plus(translation_raw)).strip()
     if translation != expected:
         print("%s: expected '%s', got '%s' (for input: %s)" % (pair, expected, translation, intext))
         return False
